pub fn clean_data_cache_line_to_poc(addr: u32)Expand description
Cleans a data cache line to the point of coherence.
See p.1735 of the ARMv7-A Architecture Reference Manual for more information.
pub fn clean_data_cache_line_to_poc(addr: u32)Cleans a data cache line to the point of coherence.
See p.1735 of the ARMv7-A Architecture Reference Manual for more information.