pub fn invalidate_data_cache_line_to_poc(addr: u32)Expand description
Invalidates a data cache line to the point of coherence.
See p.1735 of the ARMv7-A Architecture Reference Manual for more information.
pub fn invalidate_data_cache_line_to_poc(addr: u32)Invalidates a data cache line to the point of coherence.
See p.1735 of the ARMv7-A Architecture Reference Manual for more information.