pub struct El0PhysicalTimer();Expand description
Represents our Generic Physical Timer when we are running at EL0.
Note that for most of these APIs to work, EL0 needs to have been granted access using methods like El1PhysicalTimer::el0_access_physical_counter.
Implementations
Sourceimpl El0PhysicalTimer
impl El0PhysicalTimer
Sourcepub unsafe fn new() -> El0PhysicalTimer
pub unsafe fn new() -> El0PhysicalTimer
Create an EL0 Timer handle for the Physical Timer.
EL2/EL1 has to grant permission for EL0 to use the Physical Timer, so check they did that.
Safety
Only create one of these at any given time, as they access shared mutable state within the processor and do read-modify-writes on that state.