El0VirtualTimer

Struct El0VirtualTimer 

pub struct El0VirtualTimer();
Represents our Generic Virtual Timer when we are running at EL0.

Note that for most of these APIs to work, EL0 needs to have been granted access using methods like El1VirtualTimer::el0_access_virtual_counter.

Implementations

Source

impl El0VirtualTimer

pub unsafe fn new() -> El0VirtualTimer

Create an EL0 Timer handle for the Virtual Timer.

Safety

Only create one of these at any given time, as they access shared mutable state within the processor and do read-modify-writes on that state.