pub struct El2HypPhysicalTimer();Expand description
Represents our Hypervisor-specific Physical Timer when we are running at EL1.
Implementations
Sourceimpl El2HypPhysicalTimer
impl El2HypPhysicalTimer
Sourcepub unsafe fn new() -> El2HypPhysicalTimer
pub unsafe fn new() -> El2HypPhysicalTimer
Create a Timer handle for the EL2-specific Hyp Physical Timer.
Safety
Only create one of these at any given time, as they access shared mutable state within the processor and do read-modify-writes on that state.