El2VirtualTimer

Struct El2VirtualTimer 

pub struct El2VirtualTimer(/* private fields */);
Represents our Virtual Timer when we are running at EL1.

This works exactly like El1VirtualTimer, but it gives you extra methods for functionality that only processors running at EL2 can access.

This type is not [Send] because it is a per-core type and should not be moved across cores on an SMP system.

Implementations

Source

impl El2VirtualTimer

pub unsafe fn new() -> El2VirtualTimer

Create an EL2 Virtual Timer handle

Safety

Only create one Virtual Timer handle (at any EL) at any given time, as they access shared mutable state within the processor and do read-modify-writes on that state.

pub fn frequency_hz_set(&mut self, new_frequency_hz: u32)

Set frequency

Sets the frequency, in Hz, that the counters are incrementing at. You might need to call this if your system doesn’t initialise the frequency value to something appropriate, or if you change the clock speed of the timer.