AccessPerms

Enum AccessPerms 

pub enum AccessPerms {
    NoAccess,
    ReadOnly,
    ReadWrite,
    PrivReadOnly,
    PrivReadWrite,
    PrivReadWriteUserReadOnly,
}
Describes the access permissions of a memory region

Access permission bits control read and write access to the corresponding memory region. Permissions are specified for priviledged accesses (PL1) and for user accesses (PL0). Accesses to a memory region without the required permissions generate a Permission fault.

Note that the execute-never (XN) attribute provides an additional permission check on memory regions, see Region::no_exec.

Variants



NoAccess

All accesses generate a Permission fault

  • PL1: No access
  • PL0: No access


ReadOnly

All write accesses generate Permission faults

  • PL1: Read-only
  • PL0: Read-only


ReadWrite

Full access

  • PL1: Read/Write
  • PL0: Read/Write


PrivReadOnly

PL1 read-only, all other accesses generate Permission faults

  • PL1: Read-only
  • PL0: No access


PrivReadWrite

All unprivileged accesses generate Permission faults

  • PL1: Read/Write
  • PL0: No access


PrivReadWriteUserReadOnly

User mode write accesses generate Permission faults

  • PL1: Read/Write
  • PL0: Read-only

Implementations

Source

impl AccessPerms

pub const fn to_bits(&self) -> u3

Convert these access permissions to a 3-bit value we can write to RACR