pub struct Csselr { /* private fields */ }Expand description
CSSELR (Cache Size Selection Register)
Implementations
Sourceimpl Csselr
impl Csselr
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> Csselr
pub const fn new_with_raw_value(value: u32) -> Csselr
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialCsselr<false, false>
pub const fn builder() -> PartialCsselr<false, false>
Creates a builder for this bitfield which ensures that all writable fields are initialized.
Sourcepub const fn with_level(&self, field_value: u3) -> Self
pub const fn with_level(&self, field_value: u3) -> Self
0 for L1 cache, 1 for L2, etc.
Sourcepub const fn cache_type(&self) -> CacheType
pub const fn cache_type(&self) -> CacheType
The type of cache
Sourcepub const fn with_cache_type(&self, field_value: CacheType) -> Self
pub const fn with_cache_type(&self, field_value: CacheType) -> Self
The type of cache
Sourcepub fn set_cache_type(&mut self, field_value: CacheType)
pub fn set_cache_type(&mut self, field_value: CacheType)
The type of cache