pub enum DomainAccess {
NoAccess = 0,
Client = 1,
Reserved = 2,
Manager = 3,
}Expand description
Domain Access Permissions
Variants
NoAccess = 0
No access. Any access to the domain generates a Domain fault.
Client = 1
Cient. Accesses are checked against the permission bits in the translation tables.
Reserved = 2
Reserved
Manager = 3
Manager. Accesses are not checked against the permission bits in the translation tables.
Implementations
Sourceimpl DomainAccess
impl DomainAccess