DfsrStatus

Enum DfsrStatus 

#[repr(u8)]
pub enum DfsrStatus { AlignmentFault = 1, Debug = 2, Translation = 4, Permission = 12, SError = 16, SErrorInterrupt = 17, SyncParErrorOnMemAccess = 24, SErrorParityEccError = 25, }
Fault status register enumeration for DFSR

Variants



AlignmentFault = 1

Alignment fault



Debug = 2

Debug exception



Translation = 4

Translation fault



Permission = 12

Permission fault



SError = 16

Synchronous external abort, other than synchronous parity or ECC error



SErrorInterrupt = 17

SError interrupt



SyncParErrorOnMemAccess = 24

Synchronous parity or ECC error on memory access



SErrorParityEccError = 25

SError parity or ECC error on memory access

Implementations

Source

impl DfsrStatus

pub const fn raw_value(self) -> UInt<u8, 5usize>

Returns the underlying raw value of this bitfield.

pub const fn new_with_raw_value( value: UInt<u8, 5usize>, ) -> Result<Self, UInt<u8, 5usize>>

Creates a new instance of this bitfield with the given raw value.