Dfsr

Struct Dfsr 

pub struct Dfsr { /* private fields */ }
DFSR (Data Fault Status Register)

Implementations

Source

impl Dfsr

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const fn raw_value(&self) -> u32

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u32) -> Dfsr

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialDfsr<false>

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn status(&self) -> Result<DfsrStatus, u5>

Status bitfield.

pub const fn with_status(&self, field_value: DfsrStatus) -> Self

Status bitfield.

pub fn set_status(&mut self, field_value: DfsrStatus)

Status bitfield.

Source

impl Dfsr

pub fn read() -> Dfsr

Reads DFSR (Data Fault Status Register)

Source

impl Dfsr

pub unsafe fn write(value: Self)

Writes DFSR (Data Fault Status Register)

Safety

Ensure that this value is appropriate for this register