Cnthctl

Struct Cnthctl 

pub struct Cnthctl { /* private fields */ }
CNTHCTL (Hyp Counter-timer Control Register)

Implementations

Source

impl Cnthctl

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const fn raw_value(&self) -> u32

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u32) -> Cnthctl

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialCnthctl<false, false, false, false, false>

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn evnti(&self) -> u4

Selects which bit of CNTPCT, as seen from EL2, is the trigger for the event stream generated from that counter when that stream is enabled.

pub const fn with_evnti(&self, field_value: u4) -> Self

Selects which bit of CNTPCT, as seen from EL2, is the trigger for the event stream generated from that counter when that stream is enabled.

pub fn set_evnti(&mut self, field_value: u4)

Selects which bit of CNTPCT, as seen from EL2, is the trigger for the event stream generated from that counter when that stream is enabled.

pub const fn evntdir(&self) -> bool

Controls which transition of the CNTPCT trigger bit, as seen from EL2 and defined by EVNTI, generates an event when the event stream is enabled.

pub const fn with_evntdir(&self, field_value: bool) -> Self

Controls which transition of the CNTPCT trigger bit, as seen from EL2 and defined by EVNTI, generates an event when the event stream is enabled.

pub fn set_evntdir(&mut self, field_value: bool)

Controls which transition of the CNTPCT trigger bit, as seen from EL2 and defined by EVNTI, generates an event when the event stream is enabled.

pub const fn evnten(&self) -> bool

Enables the generation of an event stream from CNTPCT as seen from EL2.

pub const fn with_evnten(&self, field_value: bool) -> Self

Enables the generation of an event stream from CNTPCT as seen from EL2.

pub fn set_evnten(&mut self, field_value: bool)

Enables the generation of an event stream from CNTPCT as seen from EL2.

pub const fn pl1pcen(&self) -> bool

Traps Non-secure EL0 and EL1 MRC or MCR accesses, reported using EC syndrome value 0x03, and MRRC or MCRR accesses, reported using EC syndrome value 0x04, to the physical timer registers to Hyp mode.

pub const fn with_pl1pcen(&self, field_value: bool) -> Self

Traps Non-secure EL0 and EL1 MRC or MCR accesses, reported using EC syndrome value 0x03, and MRRC or MCRR accesses, reported using EC syndrome value 0x04, to the physical timer registers to Hyp mode.

pub fn set_pl1pcen(&mut self, field_value: bool)

Traps Non-secure EL0 and EL1 MRC or MCR accesses, reported using EC syndrome value 0x03, and MRRC or MCRR accesses, reported using EC syndrome value 0x04, to the physical timer registers to Hyp mode.

pub const fn pl1pcten(&self) -> bool

Traps Non-secure EL0 and EL1 MRRC or MCRR accesses, reported using EC syndrome value 0x04, to the physical counter register to Hyp mode.

pub const fn with_pl1pcten(&self, field_value: bool) -> Self

Traps Non-secure EL0 and EL1 MRRC or MCRR accesses, reported using EC syndrome value 0x04, to the physical counter register to Hyp mode.

pub fn set_pl1pcten(&mut self, field_value: bool)

Traps Non-secure EL0 and EL1 MRRC or MCRR accesses, reported using EC syndrome value 0x04, to the physical counter register to Hyp mode.

Source

impl Cnthctl

pub fn read() -> Cnthctl

Reads CNTHCTL (Hyp Counter-timer Control Register)

Source

impl Cnthctl

pub fn write(value: Self)

Writes CNTHCTL (Hyp Counter-timer Control Register)