PartialCnthctl

Struct PartialCnthctl 

pub struct PartialCnthctl<const evnti: bool, const evntdir: bool, const evnten: bool, const pl1pcen: bool, const pl1pcten: bool> { /* private fields */ }
Builder struct for partial initialization of Cnthctl .

Implementations

Source

impl<const evntdir: bool, const evnten: bool, const pl1pcen: bool, const pl1pcten: bool> PartialCnthctl<false, evntdir, evnten, pl1pcen, pl1pcten>

pub const fn with_evnti( &self, value: u4, ) -> PartialCnthctl<true, evntdir, evnten, pl1pcen, pl1pcten>

Selects which bit of CNTPCT, as seen from EL2, is the trigger for the event stream generated from that counter when that stream is enabled.

Source

impl<const evnti: bool, const evnten: bool, const pl1pcen: bool, const pl1pcten: bool> PartialCnthctl<evnti, false, evnten, pl1pcen, pl1pcten>

pub const fn with_evntdir( &self, value: bool, ) -> PartialCnthctl<evnti, true, evnten, pl1pcen, pl1pcten>

Controls which transition of the CNTPCT trigger bit, as seen from EL2 and defined by EVNTI, generates an event when the event stream is enabled.

Source

impl<const evnti: bool, const evntdir: bool, const pl1pcen: bool, const pl1pcten: bool> PartialCnthctl<evnti, evntdir, false, pl1pcen, pl1pcten>

pub const fn with_evnten( &self, value: bool, ) -> PartialCnthctl<evnti, evntdir, true, pl1pcen, pl1pcten>

Enables the generation of an event stream from CNTPCT as seen from EL2.

Source

impl<const evnti: bool, const evntdir: bool, const evnten: bool, const pl1pcten: bool> PartialCnthctl<evnti, evntdir, evnten, false, pl1pcten>

pub const fn with_pl1pcen( &self, value: bool, ) -> PartialCnthctl<evnti, evntdir, evnten, true, pl1pcten>

Traps Non-secure EL0 and EL1 MRC or MCR accesses, reported using EC syndrome value 0x03, and MRRC or MCRR accesses, reported using EC syndrome value 0x04, to the physical timer registers to Hyp mode.

Source

impl<const evnti: bool, const evntdir: bool, const evnten: bool, const pl1pcen: bool> PartialCnthctl<evnti, evntdir, evnten, pl1pcen, false>

pub const fn with_pl1pcten( &self, value: bool, ) -> PartialCnthctl<evnti, evntdir, evnten, pl1pcen, true>

Traps Non-secure EL0 and EL1 MRRC or MCRR accesses, reported using EC syndrome value 0x04, to the physical counter register to Hyp mode.