PartialCntkctl

Struct PartialCntkctl 

pub struct PartialCntkctl<const el0pten: bool, const el0vten: bool, const evnti: bool, const evntdir: bool, const evnten: bool, const el0vcten: bool, const el0pcten: bool> { /* private fields */ }
Builder struct for partial initialization of Cntkctl .

Implementations

Source

impl<const el0vten: bool, const evnti: bool, const evntdir: bool, const evnten: bool, const el0vcten: bool, const el0pcten: bool> PartialCntkctl<false, el0vten, evnti, evntdir, evnten, el0vcten, el0pcten>

pub const fn with_el0pten( &self, value: bool, ) -> PartialCntkctl<true, el0vten, evnti, evntdir, evnten, el0vcten, el0pcten>

Controls whether the physical timer registers are accessible from EL0 modes.

Source

impl<const el0pten: bool, const evnti: bool, const evntdir: bool, const evnten: bool, const el0vcten: bool, const el0pcten: bool> PartialCntkctl<el0pten, false, evnti, evntdir, evnten, el0vcten, el0pcten>

pub const fn with_el0vten( &self, value: bool, ) -> PartialCntkctl<el0pten, true, evnti, evntdir, evnten, el0vcten, el0pcten>

Controls whether the virtual timer registers are accessible from EL0 modes.

Source

impl<const el0pten: bool, const el0vten: bool, const evntdir: bool, const evnten: bool, const el0vcten: bool, const el0pcten: bool> PartialCntkctl<el0pten, el0vten, false, evntdir, evnten, el0vcten, el0pcten>

pub const fn with_evnti( &self, value: u4, ) -> PartialCntkctl<el0pten, el0vten, true, evntdir, evnten, el0vcten, el0pcten>

Selects which bit of CNTVCT is the trigger for the event stream generated from the virtual counter, when that stream is enabled.

Source

impl<const el0pten: bool, const el0vten: bool, const evnti: bool, const evnten: bool, const el0vcten: bool, const el0pcten: bool> PartialCntkctl<el0pten, el0vten, evnti, false, evnten, el0vcten, el0pcten>

pub const fn with_evntdir( &self, value: bool, ) -> PartialCntkctl<el0pten, el0vten, evnti, true, evnten, el0vcten, el0pcten>

Controls which transition of the CNTVCT trigger bit, defined by EVNTI, generates an event, when the event stream is enabled.

  • true: a 1-0 transition
  • false: a 0-1 transition
Source

impl<const el0pten: bool, const el0vten: bool, const evnti: bool, const evntdir: bool, const el0vcten: bool, const el0pcten: bool> PartialCntkctl<el0pten, el0vten, evnti, evntdir, false, el0vcten, el0pcten>

pub const fn with_evnten( &self, value: bool, ) -> PartialCntkctl<el0pten, el0vten, evnti, evntdir, true, el0vcten, el0pcten>

Enables the generation of an event stream from the virtual counter.

Source

impl<const el0pten: bool, const el0vten: bool, const evnti: bool, const evntdir: bool, const evnten: bool, const el0pcten: bool> PartialCntkctl<el0pten, el0vten, evnti, evntdir, evnten, false, el0pcten>

pub const fn with_el0vcten( &self, value: bool, ) -> PartialCntkctl<el0pten, el0vten, evnti, evntdir, evnten, true, el0pcten>

Controls whether the virtual counter, CNTVCT, and the frequency register CNTFRQ, are accessible from EL0 modes.

Source

impl<const el0pten: bool, const el0vten: bool, const evnti: bool, const evntdir: bool, const evnten: bool, const el0vcten: bool> PartialCntkctl<el0pten, el0vten, evnti, evntdir, evnten, el0vcten, false>

pub const fn with_el0pcten( &self, value: bool, ) -> PartialCntkctl<el0pten, el0vten, evnti, evntdir, evnten, el0vcten, true>

Controls whether the physical counter, CNTPCT, and the frequency register CNTFRQ, are accessible from EL0 modes.