Hcptr

Struct Hcptr 

pub struct Hcptr { /* private fields */ }
HCPTR (Hyp Architectural Feature Trap Register)

Implementations

Source

impl Hcptr

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const fn raw_value(&self) -> u32

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u32) -> Hcptr

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialHcptr<false, false, false, false>

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn tcpac(&self) -> bool

TCPAC - Traps EL1 accesses to the CPACR to Hyp mode

pub const fn with_tcpac(&self, field_value: bool) -> Self

TCPAC - Traps EL1 accesses to the CPACR to Hyp mode

pub fn set_tcpac(&mut self, field_value: bool)

TCPAC - Traps EL1 accesses to the CPACR to Hyp mode

pub const fn tta(&self) -> bool

TTA - Traps System register accesses to all implemented trace registers to Hyp mode

pub const fn with_tta(&self, field_value: bool) -> Self

TTA - Traps System register accesses to all implemented trace registers to Hyp mode

pub fn set_tta(&mut self, field_value: bool)

TTA - Traps System register accesses to all implemented trace registers to Hyp mode

pub const fn tase(&self) -> bool

TASE - Traps execution of Advanced SIMD instructions to Hyp mode when the value of HCPTR.TCP10 is 0.

pub const fn with_tase(&self, field_value: bool) -> Self

TASE - Traps execution of Advanced SIMD instructions to Hyp mode when the value of HCPTR.TCP10 is 0.

pub fn set_tase(&mut self, field_value: bool)

TASE - Traps execution of Advanced SIMD instructions to Hyp mode when the value of HCPTR.TCP10 is 0.

pub const fn tcp(&self) -> bool

TCP - Trap accesses to Advanced SIMD and floating-point functionality to Hyp mode

pub const fn with_tcp(&self, field_value: bool) -> Self

TCP - Trap accesses to Advanced SIMD and floating-point functionality to Hyp mode

pub fn set_tcp(&mut self, field_value: bool)

TCP - Trap accesses to Advanced SIMD and floating-point functionality to Hyp mode

Source

impl Hcptr

pub fn read() -> Hcptr

Reads HCPTR (Hyp Architectural Feature Trap Register)

pub fn modify<F>(f: F)
where F: FnOnce(&mut Self),

Modify HCPTR (Hyp Architectural Feature Trap Register)

Source

impl Hcptr

pub fn write(value: Self)

Writes HCPTR (Hyp Architectural Feature Trap Register)