PartialHcptr

Struct PartialHcptr 

pub struct PartialHcptr<const tcpac: bool, const tta: bool, const tase: bool, const tcp: bool> { /* private fields */ }
Builder struct for partial initialization of Hcptr .

Implementations

Source

impl<const tta: bool, const tase: bool, const tcp: bool> PartialHcptr<false, tta, tase, tcp>

pub const fn with_tcpac( &self, value: bool, ) -> PartialHcptr<true, tta, tase, tcp>

TCPAC - Traps EL1 accesses to the CPACR to Hyp mode

Source

impl<const tcpac: bool, const tase: bool, const tcp: bool> PartialHcptr<tcpac, false, tase, tcp>

pub const fn with_tta( &self, value: bool, ) -> PartialHcptr<tcpac, true, tase, tcp>

TTA - Traps System register accesses to all implemented trace registers to Hyp mode

Source

impl<const tcpac: bool, const tta: bool, const tcp: bool> PartialHcptr<tcpac, tta, false, tcp>

pub const fn with_tase( &self, value: bool, ) -> PartialHcptr<tcpac, tta, true, tcp>

TASE - Traps execution of Advanced SIMD instructions to Hyp mode when the value of HCPTR.TCP10 is 0.

Source

impl<const tcpac: bool, const tta: bool, const tase: bool> PartialHcptr<tcpac, tta, tase, false>

pub const fn with_tcp( &self, value: bool, ) -> PartialHcptr<tcpac, tta, tase, true>

TCP - Trap accesses to Advanced SIMD and floating-point functionality to Hyp mode