IssDataAbort

Struct IssDataAbort 

pub struct IssDataAbort { /* private fields */ }
The ISS field when EC = ExceptionClass::DataAbortFromLower or ExceptionClass::DataAbortFromCurrent

Implementations

Source

impl IssDataAbort

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(u25 :: new(0))].

pub const fn raw_value(&self) -> u25

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u25) -> IssDataAbort

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialIssDataAbort

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn isv(&self) -> bool

Instruction Syndrome Valid

pub const fn sas(&self) -> u2

Syndrome Access Size

pub const fn sae(&self) -> bool

Syndrome Sign Extend

pub const fn srt(&self) -> u4

Syndrome Register transfer

pub const fn ar(&self) -> bool

Acquire/Release

pub const fn fnv(&self) -> bool

FAR not Valid

pub const fn ea(&self) -> bool

External Abort Type.

External = true, anything else = false

pub const fn cm(&self) -> bool

Cache maintenance

pub const fn wnr(&self) -> bool

Write not Read

pub const fn dfsc(&self) -> u6

Data Fault Status Code