IssPrefetchAbort

Struct IssPrefetchAbort 

pub struct IssPrefetchAbort { /* private fields */ }
The ISS field when EC = ExceptionClass::PrefetchAbortFromLower or ExceptionClass::PrefetchAbortFromCurrent

Implementations

Source

impl IssPrefetchAbort

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(u25 :: new(0))].

pub const fn raw_value(&self) -> u25

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u25) -> IssPrefetchAbort

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialIssPrefetchAbort

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn fnv(&self) -> bool

FAR not Valid, for a Synchronous External abort.

pub const fn ea(&self) -> bool

External Abort Type.

External = true, anything else = false

pub const fn ifsc(&self) -> u6

Instruction Fault Status Code