IssTrappedFpu

Struct IssTrappedFpu 

pub struct IssTrappedFpu { /* private fields */ }
The ISS field when EC = ExceptionClass::TrappedFpu

Implementations

Source

impl IssTrappedFpu

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(u25 :: new(0))].

pub const fn raw_value(&self) -> u25

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u25) -> IssTrappedFpu

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialIssTrappedFpu

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn cv(&self) -> bool

Condition code valid

pub const fn cc(&self) -> u4

Condition code

pub const fn ta(&self) -> bool

Trapped Advanced SIMD

pub const fn coproc(&self) -> u4

CoProc Bits