IssTrappedLdcStc

Struct IssTrappedLdcStc 

pub struct IssTrappedLdcStc { /* private fields */ }
The ISS field when EC = ExceptionClass::TrappedLdcStc

Implementations

Source

impl IssTrappedLdcStc

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(u25 :: new(0))].

pub const fn raw_value(&self) -> u25

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u25) -> IssTrappedLdcStc

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialIssTrappedLdcStc

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn cv(&self) -> bool

Condition code valid

pub const fn cc(&self) -> u4

Condition code

pub const fn imm8(&self) -> u8

The immediate value from the instruction

pub const fn rn(&self) -> u4

Rn value from instruction

pub const fn offset(&self) -> bool

Whether offset is added (true) or subtracted (false)

pub const fn am(&self) -> u3

Addressing Mode

pub const fn is_read(&self) -> bool

Direction (true = read, false = write)