pub struct Ifsr { /* private fields */ }Expand description
IFSR (Instruction Fault Status Register)
Implementations
Sourceimpl Ifsr
impl Ifsr
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> Ifsr
pub const fn new_with_raw_value(value: u32) -> Ifsr
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialIfsr<false, false>
pub const fn builder() -> PartialIfsr<false, false>
Creates a builder for this bitfield which ensures that all writable fields are initialized.
Sourcepub const fn with_domain(&self, field_value: u4) -> Self
pub const fn with_domain(&self, field_value: u4) -> Self
Which domain was being accessed
Sourcepub fn set_domain(&mut self, field_value: u4)
pub fn set_domain(&mut self, field_value: u4)
Which domain was being accessed
Sourcepub const fn status(&self) -> Result<IfsrStatus, u5>
pub const fn status(&self) -> Result<IfsrStatus, u5>
Status bitfield.
Sourcepub const fn with_status(&self, field_value: IfsrStatus) -> Self
pub const fn with_status(&self, field_value: IfsrStatus) -> Self
Status bitfield.
Sourcepub fn set_status(&mut self, field_value: IfsrStatus)
pub fn set_status(&mut self, field_value: IfsrStatus)
Status bitfield.