Midr

Struct Midr 

pub struct Midr { /* private fields */ }
MIDR (Main ID Register)

Implementations

Source

impl Midr

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const fn raw_value(&self) -> u32

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u32) -> Midr

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialMidr

Creates a builder for this bitfield which ensures that all writable fields are initialized.

pub const fn implementer(&self) -> u8

Implementer

pub const fn variant(&self) -> u4

Variant

pub const fn arch(&self) -> u4

Architecture

pub const fn part_no(&self) -> u12

Part Number

pub const fn rev(&self) -> u4

Revision

Source

impl Midr

pub fn read() -> Midr

Read MIDR (Main ID Register)