PartialSctlr

Struct PartialSctlr 

pub struct PartialSctlr<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> { /* private fields */ }
Builder struct for partial initialization of Sctlr .

Implementations

Source

impl<const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<false, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, c, a, m>

pub const fn with_ie( &self, value: bool, ) -> PartialSctlr<true, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, c, a, m>

The bitmask for the Instruction Endianness bit

Source

impl<const ie: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, false, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, c, a, m>

pub const fn with_te( &self, value: bool, ) -> PartialSctlr<ie, true, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, c, a, m>

The bitmask for the Thumb Exception Enable bit

Source

impl<const ie: bool, const te: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, false, ee, u, fi, dz, br, rr, v, i, z, sw, c, a, m>

pub const fn with_nmfi( &self, value: bool, ) -> PartialSctlr<ie, te, true, ee, u, fi, dz, br, rr, v, i, z, sw, c, a, m>

The bitmask for the Non-Maskable FIQ bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, false, u, fi, dz, br, rr, v, i, z, sw, c, a, m>

pub const fn with_ee( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, true, u, fi, dz, br, rr, v, i, z, sw, c, a, m>

The bitmask for the Exception Endianness bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, false, fi, dz, br, rr, v, i, z, sw, c, a, m>

pub const fn with_u( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, true, fi, dz, br, rr, v, i, z, sw, c, a, m>

The bitmask for the U bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, false, dz, br, rr, v, i, z, sw, c, a, m>

pub const fn with_fi( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, true, dz, br, rr, v, i, z, sw, c, a, m>

The bitmask for the Fast Interrupt bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, false, br, rr, v, i, z, sw, c, a, m>

pub const fn with_dz( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, true, br, rr, v, i, z, sw, c, a, m>

The bitmask for the Divide by Zero Fault bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, false, rr, v, i, z, sw, c, a, m>

pub const fn with_br( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, true, rr, v, i, z, sw, c, a, m>

The bitmask for the Background Region bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, false, v, i, z, sw, c, a, m>

pub const fn with_rr( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, true, v, i, z, sw, c, a, m>

The bitmask for the Round Robin bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, false, i, z, sw, c, a, m>

pub const fn with_v( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, true, i, z, sw, c, a, m>

The bitmask for the Exception Vector Table bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const z: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, false, z, sw, c, a, m>

pub const fn with_i( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, true, z, sw, c, a, m>

The bitmask for the Instruction Cache enable bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const sw: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, false, sw, c, a, m>

pub const fn with_z( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, true, sw, c, a, m>

The bitmask for the Branch Prediction enable bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const c: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, false, c, a, m>

pub const fn with_sw( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, true, c, a, m>

The bitmask for the SWP bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const a: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, false, a, m>

pub const fn with_c( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, true, a, m>

The bitmask for the Cache enable bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const m: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, c, false, m>

pub const fn with_a( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, c, true, m>

The bitmask for the Alignment check bit

Source

impl<const ie: bool, const te: bool, const nmfi: bool, const ee: bool, const u: bool, const fi: bool, const dz: bool, const br: bool, const rr: bool, const v: bool, const i: bool, const z: bool, const sw: bool, const c: bool, const a: bool> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, c, a, false>

pub const fn with_m( &self, value: bool, ) -> PartialSctlr<ie, te, nmfi, ee, u, fi, dz, br, rr, v, i, z, sw, c, a, true>

The bitmask for the MPU bit