SysRegRead64

Trait SysRegRead64 

pub trait SysRegRead64: SysReg64 {
    // Provided method
    fn read_raw() -> u64 { ... }
}
Readable 64-bit System Registers

Provided Methods

fn read_raw() -> u64

Read a value from this 64-bit register

Our working assumption is that no Arm system register read has side-effects that can cause Undefined Behaviour, so this method is safe.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors