pub struct El1PhysicalTimer(/* private fields */);Expand description
Represents our Physical Timer when we are running at EL1.
Implementations
Sourceimpl El1PhysicalTimer
impl El1PhysicalTimer
Sourcepub unsafe fn new() -> El1PhysicalTimer
pub unsafe fn new() -> El1PhysicalTimer
Create an EL1 Generic Timer handle
Safety
Only create one of these at any given time, as they access shared mutable state within the processor and do read-modify-writes on that state.
Sourcepub fn el0_access_physical_counter(&mut self, access: bool)
pub fn el0_access_physical_counter(&mut self, access: bool)
Control whether user code at EL0 can access the physical counter.
Sourcepub fn el0_access_physical_timer(&mut self, access: bool)
pub fn el0_access_physical_timer(&mut self, access: bool)
Control whether user code at EL0 can access the physical timer.