El2HypPhysicalTimer

Struct El2HypPhysicalTimer 

pub struct El2HypPhysicalTimer { /* private fields */ }
Represents our Hypervisor-specific Physical Timer.

This is designed for use by a hypervisor, whilst an EL1 application concurrently uses the Physical Timer and/or the Virtual Timer.

This type is not [Send] because it is a per-core type and should not be moved across cores on an SMP system.

Implementations

Source

impl El2HypPhysicalTimer

pub unsafe fn new() -> El2HypPhysicalTimer

Create a Timer handle for the EL2-specific Hyp Physical Timer.

Safety

Only create one of these at any given time, as they access shared mutable state within the processor and do read-modify-writes on that state. This timer is distinct from the Physical Timer and the Virtual Timer, and so can exist concurrently.