pub struct Region {
pub base: *mut u8,
pub size: RegionSize,
pub subregion_mask: u8,
pub enabled: bool,
pub no_exec: bool,
pub mem_attr: MemAttr,
}Expand description
Configuration for a region in the PMSAv7 MPU
Fields
base: *mut u8The base address of this region.
Must be aligned to the size of the region.
size: RegionSizeThe size of this region
subregion_mask: u8Sub-region bitmask
The region is divided into exactly eight equal sized subregions. Subregion 0 is the subregion at the least significant address.
A 1 bit means that sub-region is disabled.
Only applies to regions sized 256 bytes or larger.
enabled: boolIs this region enabled?
no_exec: boolNo-Execute in this region
mem_attr: MemAttrAttributes for this region