pub struct Dfsr { /* private fields */ }Expand description
DFSR (Data Fault Status Register)
Implementations
Sourceimpl Dfsr
impl Dfsr
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> Dfsr
pub const fn new_with_raw_value(value: u32) -> Dfsr
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialDfsr<false>
pub const fn builder() -> PartialDfsr<false>
Creates a builder for this bitfield which ensures that all writable fields are initialized.
Sourcepub const fn status(&self) -> Result<DfsrStatus, u5>
pub const fn status(&self) -> Result<DfsrStatus, u5>
Status bitfield.
Sourcepub const fn with_status(&self, field_value: DfsrStatus) -> Self
pub const fn with_status(&self, field_value: DfsrStatus) -> Self
Status bitfield.
Sourcepub fn set_status(&mut self, field_value: DfsrStatus)
pub fn set_status(&mut self, field_value: DfsrStatus)
Status bitfield.