pub struct Cntkctl { /* private fields */ }Expand description
CNTKCTL (Counter-timer Kernel Control Register)
Implementations
Sourceimpl Cntkctl
impl Cntkctl
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> Cntkctl
pub const fn new_with_raw_value(value: u32) -> Cntkctl
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialCntkctl<false, false, false, false, false, false, false>
pub const fn builder() -> PartialCntkctl<false, false, false, false, false, false, false>
Creates a builder for this bitfield which ensures that all writable fields are initialized.
Sourcepub const fn el0pten(&self) -> bool
pub const fn el0pten(&self) -> bool
Controls whether the physical timer registers are accessible from EL0 modes.
Sourcepub const fn with_el0pten(&self, field_value: bool) -> Self
pub const fn with_el0pten(&self, field_value: bool) -> Self
Controls whether the physical timer registers are accessible from EL0 modes.
Sourcepub fn set_el0pten(&mut self, field_value: bool)
pub fn set_el0pten(&mut self, field_value: bool)
Controls whether the physical timer registers are accessible from EL0 modes.
Sourcepub const fn el0vten(&self) -> bool
pub const fn el0vten(&self) -> bool
Controls whether the virtual timer registers are accessible from EL0 modes.
Sourcepub const fn with_el0vten(&self, field_value: bool) -> Self
pub const fn with_el0vten(&self, field_value: bool) -> Self
Controls whether the virtual timer registers are accessible from EL0 modes.
Sourcepub fn set_el0vten(&mut self, field_value: bool)
pub fn set_el0vten(&mut self, field_value: bool)
Controls whether the virtual timer registers are accessible from EL0 modes.
Sourcepub const fn evnti(&self) -> u4
pub const fn evnti(&self) -> u4
Selects which bit of CNTVCT is the trigger for the event stream generated from the virtual counter, when that stream is enabled.
Sourcepub const fn with_evnti(&self, field_value: u4) -> Self
pub const fn with_evnti(&self, field_value: u4) -> Self
Selects which bit of CNTVCT is the trigger for the event stream generated from the virtual counter, when that stream is enabled.
Sourcepub fn set_evnti(&mut self, field_value: u4)
pub fn set_evnti(&mut self, field_value: u4)
Selects which bit of CNTVCT is the trigger for the event stream generated from the virtual counter, when that stream is enabled.
Sourcepub const fn evntdir(&self) -> bool
pub const fn evntdir(&self) -> bool
Controls which transition of the CNTVCT trigger bit, defined by EVNTI, generates an event, when the event stream is enabled.
- true: a 1-0 transition
- false: a 0-1 transition
Sourcepub const fn with_evntdir(&self, field_value: bool) -> Self
pub const fn with_evntdir(&self, field_value: bool) -> Self
Controls which transition of the CNTVCT trigger bit, defined by EVNTI, generates an event, when the event stream is enabled.
- true: a 1-0 transition
- false: a 0-1 transition
Sourcepub fn set_evntdir(&mut self, field_value: bool)
pub fn set_evntdir(&mut self, field_value: bool)
Controls which transition of the CNTVCT trigger bit, defined by EVNTI, generates an event, when the event stream is enabled.
- true: a 1-0 transition
- false: a 0-1 transition
Sourcepub const fn evnten(&self) -> bool
pub const fn evnten(&self) -> bool
Enables the generation of an event stream from the virtual counter.
Sourcepub const fn with_evnten(&self, field_value: bool) -> Self
pub const fn with_evnten(&self, field_value: bool) -> Self
Enables the generation of an event stream from the virtual counter.
Sourcepub fn set_evnten(&mut self, field_value: bool)
pub fn set_evnten(&mut self, field_value: bool)
Enables the generation of an event stream from the virtual counter.
Sourcepub const fn el0vcten(&self) -> bool
pub const fn el0vcten(&self) -> bool
Controls whether the virtual counter, CNTVCT, and the frequency register CNTFRQ, are accessible from EL0 modes.
Sourcepub const fn with_el0vcten(&self, field_value: bool) -> Self
pub const fn with_el0vcten(&self, field_value: bool) -> Self
Controls whether the virtual counter, CNTVCT, and the frequency register CNTFRQ, are accessible from EL0 modes.
Sourcepub fn set_el0vcten(&mut self, field_value: bool)
pub fn set_el0vcten(&mut self, field_value: bool)
Controls whether the virtual counter, CNTVCT, and the frequency register CNTFRQ, are accessible from EL0 modes.
Sourcepub const fn el0pcten(&self) -> bool
pub const fn el0pcten(&self) -> bool
Controls whether the physical counter, CNTPCT, and the frequency register CNTFRQ, are accessible from EL0 modes.
Sourcepub const fn with_el0pcten(&self, field_value: bool) -> Self
pub const fn with_el0pcten(&self, field_value: bool) -> Self
Controls whether the physical counter, CNTPCT, and the frequency register CNTFRQ, are accessible from EL0 modes.
Sourcepub fn set_el0pcten(&mut self, field_value: bool)
pub fn set_el0pcten(&mut self, field_value: bool)
Controls whether the physical counter, CNTPCT, and the frequency register CNTFRQ, are accessible from EL0 modes.