pub struct Hcptr { /* private fields */ }Expand description
HCPTR (Hyp Architectural Feature Trap Register)
Implementations
Sourceimpl Hcptr
impl Hcptr
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> Hcptr
pub const fn new_with_raw_value(value: u32) -> Hcptr
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialHcptr<false, false, false, false>
pub const fn builder() -> PartialHcptr<false, false, false, false>
Creates a builder for this bitfield which ensures that all writable fields are initialized.
Sourcepub const fn with_tcpac(&self, field_value: bool) -> Self
pub const fn with_tcpac(&self, field_value: bool) -> Self
TCPAC - Traps EL1 accesses to the CPACR to Hyp mode
Sourcepub fn set_tcpac(&mut self, field_value: bool)
pub fn set_tcpac(&mut self, field_value: bool)
TCPAC - Traps EL1 accesses to the CPACR to Hyp mode
Sourcepub const fn tta(&self) -> bool
pub const fn tta(&self) -> bool
TTA - Traps System register accesses to all implemented trace registers to Hyp mode
Sourcepub const fn with_tta(&self, field_value: bool) -> Self
pub const fn with_tta(&self, field_value: bool) -> Self
TTA - Traps System register accesses to all implemented trace registers to Hyp mode
Sourcepub fn set_tta(&mut self, field_value: bool)
pub fn set_tta(&mut self, field_value: bool)
TTA - Traps System register accesses to all implemented trace registers to Hyp mode
Sourcepub const fn tase(&self) -> bool
pub const fn tase(&self) -> bool
TASE - Traps execution of Advanced SIMD instructions to Hyp mode when the value of HCPTR.TCP10 is 0.
Sourcepub const fn with_tase(&self, field_value: bool) -> Self
pub const fn with_tase(&self, field_value: bool) -> Self
TASE - Traps execution of Advanced SIMD instructions to Hyp mode when the value of HCPTR.TCP10 is 0.
Sourcepub fn set_tase(&mut self, field_value: bool)
pub fn set_tase(&mut self, field_value: bool)
TASE - Traps execution of Advanced SIMD instructions to Hyp mode when the value of HCPTR.TCP10 is 0.
Sourcepub const fn tcp(&self) -> bool
pub const fn tcp(&self) -> bool
TCP - Trap accesses to Advanced SIMD and floating-point functionality to Hyp mode