pub enum ExceptionClass {
Show 18 variants
Unknown = 0,
TrappedWfiWfe = 1,
TrappedCp15McrMrc = 3,
TrappedCp15McrrMrrc = 4,
TrappedCp14McrMrc = 5,
TrappedLdcStc = 6,
TrappedFpu = 7,
TrappedVmrs = 8,
TrappedCp14McrrMrrc = 12,
IllegalAArch32Eret = 14,
Svc = 17,
Hvc = 18,
Smc = 19,
PrefetchAbortFromLower = 32,
PrefetchAbortFromCurrent = 33,
PcAlignment = 34,
DataAbortFromLower = 36,
DataAbortFromCurrent = 37,
}Expand description
Exception Class value from the HSR (Hyp Syndrome Register)
Variants
Unknown = 0
Unknown reason
TrappedWfiWfe = 1
Trapped WFI or WFE instruction execution
TrappedCp15McrMrc = 3
Trapped MCR or MRC access with (coproc==0b1111) that is not reported using EC value `0b000000``
TrappedCp15McrrMrrc = 4
Trapped MCRR or MRRC access with (coproc==0b1111) that is not reported using EC value `0b000000``
TrappedCp14McrMrc = 5
Trapped MCR or MRC access with (coproc==`0b1110``)
TrappedLdcStc = 6
Trapped LDC or STC access
TrappedFpu = 7
Access to Advanced SIMD or floating-point functionality trapped by a HCPTR.{TASE, TCP10} control
TrappedVmrs = 8
Trapped VMRS access, from ID group trap, that is not reported using EC value 0b000111
TrappedCp14McrrMrrc = 12
Trapped MRRC access with (coproc==0b1110)
IllegalAArch32Eret = 14
Illegal exception return to AArch32 state
Svc = 17
Exception on SVC instruction execution in AArch32 state routed to EL2
Hvc = 18
HVC instruction execution in AArch32 state, when HVC is not disabled
Smc = 19
Trapped execution of SMC instruction in AArch32 state
PrefetchAbortFromLower = 32
Prefetch Abort from a lower Exception level
PrefetchAbortFromCurrent = 33
Prefetch Abort taken without a change in Exception level
PcAlignment = 34
PC alignment fault exception
DataAbortFromLower = 36
Data Abort exception from a lower Exception level
DataAbortFromCurrent = 37
Data Abort exception taken without a change in Exception level
Implementations
Sourceimpl ExceptionClass
impl ExceptionClass
Sourcepub fn decode_iss(&self, iss: u25) -> Iss
pub fn decode_iss(&self, iss: u25) -> Iss
Convert an ISS value based on the Exception Class