pub struct IssCall { /* private fields */ }Expand description
The ISS field when EC = ExceptionClass::Svc
Implementations
Sourceimpl IssCall
impl IssCall
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(u25 :: new(0))].
Sourcepub const fn new_with_raw_value(value: u25) -> IssCall
pub const fn new_with_raw_value(value: u25) -> IssCall
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialIssCall
pub const fn builder() -> PartialIssCall
Creates a builder for this bitfield which ensures that all writable fields are initialized.