pub struct IssPrefetchAbort { /* private fields */ }Expand description
The ISS field when EC = ExceptionClass::PrefetchAbortFromLower or ExceptionClass::PrefetchAbortFromCurrent
Implementations
Sourceimpl IssPrefetchAbort
impl IssPrefetchAbort
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(u25 :: new(0))].
Sourcepub const fn new_with_raw_value(value: u25) -> IssPrefetchAbort
pub const fn new_with_raw_value(value: u25) -> IssPrefetchAbort
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn builder() -> PartialIssPrefetchAbort
pub const fn builder() -> PartialIssPrefetchAbort
Creates a builder for this bitfield which ensures that all writable fields are initialized.