pub unsafe fn stack_used_bytes(stack: Range<*const u32>) -> (usize, usize)Expand description
Reports stack usage as a count of bytes
It starts at the lower bound, and looks for values that are set to 0,
concluding that those values have never been used. It returns (total, used) in bytes.
Safety
Pass a range of valid, readable, memory with 32-bit aligned addresses.